==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmGlobalsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HelmGlobalsFluentImpl<A extends HelmGlobalsFluent<A>> extends BaseFluent<A> implements HelmGlobalsFluent<A>{
  public HelmGlobalsFluentImpl() {
  }
  public HelmGlobalsFluentImpl(HelmGlobals instance) {
    this.withChartHome(instance.getChartHome()); 
    this.withConfigHome(instance.getConfigHome()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String chartHome;
  private String configHome;
  private Map<String,Object> additionalProperties;
  public String getChartHome() {
    return this.chartHome;
  }
  public A withChartHome(String chartHome) {
    this.chartHome=chartHome; return (A) this;
  }
  public Boolean hasChartHome() {
    return this.chartHome != null;
  }
  public String getConfigHome() {
    return this.configHome;
  }
  public A withConfigHome(String configHome) {
    this.configHome=configHome; return (A) this;
  }
  public Boolean hasConfigHome() {
    return this.configHome != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmGlobalsFluentImpl that = (HelmGlobalsFluentImpl) o;
    if (chartHome != null ? !chartHome.equals(that.chartHome) :that.chartHome != null) return false;
    if (configHome != null ? !configHome.equals(that.configHome) :that.configHome != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(chartHome,  configHome,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (chartHome != null) { sb.append("chartHome:"); sb.append(chartHome + ","); }
    if (configHome != null) { sb.append("configHome:"); sb.append(configHome + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmGlobalsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HelmGlobalsFluentImpl<A extends HelmGlobalsFluent<A>> extends BaseFluent<A> implements HelmGlobalsFluent<A>{
  public HelmGlobalsFluentImpl() {
  }
  public HelmGlobalsFluentImpl(HelmGlobals instance) {
    if (instance != null) {
      this.withChartHome(instance.getChartHome());
      this.withConfigHome(instance.getConfigHome());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String chartHome;
  private String configHome;
  private Map<String,Object> additionalProperties;
  public String getChartHome() {
    return this.chartHome;
  }
  public A withChartHome(String chartHome) {
    this.chartHome=chartHome; return (A) this;
  }
  public Boolean hasChartHome() {
    return this.chartHome != null;
  }
  public String getConfigHome() {
    return this.configHome;
  }
  public A withConfigHome(String configHome) {
    this.configHome=configHome; return (A) this;
  }
  public Boolean hasConfigHome() {
    return this.configHome != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmGlobalsFluentImpl that = (HelmGlobalsFluentImpl) o;
    if (!java.util.Objects.equals(chartHome, that.chartHome)) return false;

    if (!java.util.Objects.equals(configHome, that.configHome)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(chartHome,  configHome,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (chartHome != null) { sb.append("chartHome:"); sb.append(chartHome + ","); }
    if (configHome != null) { sb.append("configHome:"); sb.append(configHome + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
